Enum netcore::transport::ConnectionOrigin [−][src]
pub enum ConnectionOrigin {
Inbound,
Outbound,
}Expand description
Origin of how a Connection was established.
Variants
Inbound indicates that we are the listener for this connection.
Outbound indicates that we are the dialer for this connection.
Implementations